mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Roland Dreier <rolandd@cisco.com>
To: akpm@osdl.org
Cc: linux-kernel@vger.kernel.org, openib-general@openib.org
Subject: [PATCH 2/2] [IPoIB] Handle sending of unicast RARP responses
Date: Thu, 28 Jul 2005 13:31:45 -0700	[thread overview]
Message-ID: <20057281331.6BOCwhBG35vXYVIR@cisco.com> (raw)
In-Reply-To: <20057281331.7vqhiAJ1Yc0um2je@cisco.com>

From: Hal Rosenstock <halr@voltaire.com>

RARP replies are another valid case where IPoIB may need to send a
unicast packet with no neighbour structure.

Signed-off-by: Hal Rosenstock <halr@voltaire.com>
Signed-off-by: Roland Dreier <rolandd@cisco.com>
---

 drivers/infiniband/ulp/ipoib/ipoib_main.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

0dca0f7bf82face7b700890318d5550fd542cabf
diff --git a/drivers/infiniband/ulp/ipoib/ipoib_main.c b/drivers/infiniband/ulp/ipoib/ipoib_main.c
--- a/drivers/infiniband/ulp/ipoib/ipoib_main.c
+++ b/drivers/infiniband/ulp/ipoib/ipoib_main.c
@@ -600,9 +600,10 @@ static int ipoib_start_xmit(struct sk_bu
 
 			ipoib_mcast_send(dev, (union ib_gid *) (phdr->hwaddr + 4), skb);
 		} else {
 			/* unicast GID -- should be ARP reply */
 
-			if (be16_to_cpup((u16 *) skb->data) != ETH_P_ARP) {
+			if ((be16_to_cpup((__be16 *) skb->data) != ETH_P_ARP) &&
+			    (be16_to_cpup((__be16 *) skb->data) != ETH_P_RARP)) {
 				ipoib_warn(priv, "Unicast, no %s: type %04x, QPN %06x "
 					   IPOIB_GID_FMT "\n",
 					   skb->dst ? "neigh" : "dst",
@@ -600,9 +600,10 @@ static int ipoib_start_xmit(struct sk_bu
 			ipoib_mcast_send(dev, (union ib_gid *) (phdr->hwaddr + 4), skb);
 		} else {
-			/* unicast GID -- should be ARP reply */
+			/* unicast GID -- should be ARP or RARP reply */
 

  reply	other threads:[~2005-07-28 20:33 UTC|newest]

Thread overview: 37+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2005-07-28 20:31 [PATCH 0/2] REALLY final InfiniBand updates for 2.6.13 Roland Dreier
2005-07-28 20:31 ` [PATCH 1/2] [IB/cm]: Correct CM port redirect reject codes Roland Dreier
2005-07-28 20:31   ` Roland Dreier [this message]
2005-08-04  0:58   ` yhlu
2005-08-04  1:39     ` [openib-general] " Grant Grundler
2005-08-04  4:44     ` mthca and LinuxBIOS (was: [PATCH 1/2] [IB/cm]: Correct CM port redirect reject codes) Roland Dreier
2005-08-04 16:33       ` yhlu
2005-08-04 16:36         ` mthca and LinuxBIOS Roland Dreier
2005-08-04 17:23           ` yhlu
2005-08-04 18:01             ` yhlu
2005-08-04 18:35               ` Roland Dreier
2005-08-04 19:30                 ` yhlu
2005-08-05  3:47                   ` Roland Dreier
2005-08-05 18:03                     ` yhlu
2005-08-05 18:07                       ` yhlu
2005-08-05 18:13                         ` Roland Dreier
2005-08-05 18:26                           ` yhlu
2005-08-05 19:25                             ` yhlu
2005-08-05 19:45                               ` yhlu
2005-08-05 20:28                                 ` yhlu
2005-08-05 20:38                                   ` Linus Torvalds
2005-08-05 22:00                                     ` Greg KH
2005-08-05 22:25                                       ` yhlu
2005-08-05 23:03                                         ` Greg KH
2005-08-06  5:29                                           ` [openib-general] " Grant Grundler
2005-08-05 23:06                                       ` Linus Torvalds
2005-08-05 23:59                                         ` [openib-general] " Grant Grundler
2005-08-06  4:33                                           ` Grant Grundler
2005-08-06 23:52                                             ` yhlu
2005-08-07  9:49                                             ` Ivan Kokshaysky
2005-08-05 18:11                       ` Roland Dreier
2005-08-06  0:57                       ` yhlu
2005-08-06  1:30                         ` Roland Dreier
2005-08-06  2:47                           ` yhlu
2005-08-04  6:42     ` [PATCH 1/2] [IB/cm]: Correct CM port redirect reject codes Michael S. Tsirkin
2005-08-04 18:22       ` yhlu
2005-08-08 12:21         ` Michael S. Tsirkin

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20057281331.6BOCwhBG35vXYVIR@cisco.com \
    --to=rolandd@cisco.com \
    --cc=akpm@osdl.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=openib-general@openib.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®